AcquireSyncView

Struct AcquireSyncView 

pub struct AcquireSyncView(/* private fields */);
A witness to the acquire view, containing all the events that will be observed by this thread at its next acquire fence.

In Relaxed RustBelt, SyncView corresponds to the notation V.acq

Implementations

Source

impl AcquireSyncView

pub fn new() -> Ghost<Self>

terminates

ghost

pub fn weaken(&mut self, to: Snapshot<SyncView>)

terminates

ghost

requires

*to <= (*self)@

ensures

(^self)@ == *to