pub struct ReleaseSyncView(/* private fields */);Expand description
A witness to the release view, containing all the events observed by this thread at its last release fence.
In Relaxed RustBelt, SyncView corresponds to the notation V.rel
Implementations