pub struct AcquireSyncView(/* private fields */);Expand description
A witness to the acquire view, containing all the events that will be observed by this thread at its next acquire fence.
In Relaxed RustBelt, SyncView corresponds to the notation V.acq
Implementations