ReleaseSyncView

Struct ReleaseSyncView 

pub struct ReleaseSyncView(/* private fields */);
A witness to the release view, containing all the events observed by this thread at its last release fence.

In Relaxed RustBelt, SyncView corresponds to the notation V.rel

Implementations

Source

impl ReleaseSyncView

pub fn new() -> Ghost<Self>

terminates

ghost

pub fn weaken(&mut self, to: Snapshot<SyncView>)

terminates

ghost

requires

*to <= (*self)@

ensures

(^self)@ == *to